@@ -16,9 +16,11 @@ Create Dragonfly Room2Ds from floor plate geometry (horizontal Rhino surfaces).
             be converted into Room2Ds.
         _flr_to_ceiling: A number for the height above the floor where the
             ceiling begins. Typical values range from 3 to 5 meters.
-        _name_: A base name to be used for the Room2Ds. This will be combined
-            with the index of each input _geo to yield a unique name for each
-            output Room2D.
+        _name_: Text to set the base name for the Room2D, which will also be
+            incorporated into unique Room2D identifier. This will be combined
+            with the index of each input _footprint_geo to yield a unique name
+            for each output Room2D. If the name is not provided, a random one
+            will be assigned.
         _program_: Text for the program of the Room2Ds (to be looked up in the
             ProgramType library) such as that output from the "HB List Programs"
             component. This can also be a custom ProgramType object. If no program
@@ -41,7 +43,7 @@ Create Dragonfly Room2Ds from floor plate geometry (horizontal Rhino surfaces).
 
 ghenv.Component.Name = "DF Room2D"
 ghenv.Component.NickName = 'Room2D'
-ghenv.Component.Message = '0.1.2'
+ghenv.Component.Message = '0.1.3'
 ghenv.Component.Category = "Dragonfly"
 ghenv.Component.SubCategory = '0 :: Create'
 ghenv.Component.AdditionalHelpFromDocStrings = "4"
@@ -53,6 +55,11 @@ try:
 except KeyError:  # first time that the component is running
     scriptcontext.sticky["room_count"] = 1
 
+try:  # import the core honeybee dependencies
+    from honeybee.typing import clean_and_id_string
+except ImportError as e:
+    raise ImportError('\nFailed to import honeybee:\n\t{}'.format(e))
+
 try:  # import the core dragonfly dependencies
     from dragonfly.room2d import Room2D
 except ImportError as e:
@@ -67,8 +74,9 @@ except ImportError as e:
 
 try:  # import the dragonfly-energy extension
     import dragonfly_energy
-    from honeybee_energy.lib.programtypes import program_type_by_name, office_program
-    from honeybee_energy.lib.constructionsets import construction_set_by_name
+    from honeybee_energy.lib.programtypes import program_type_by_identifier, \
+        office_program
+    from honeybee_energy.lib.constructionsets import construction_set_by_identifier
 except ImportError as e:
     if _program_ is not None:
         raise ValueError('_program_ has been specified but dragonfly-energy '
@@ -80,24 +88,30 @@ except ImportError as e:
         raise ValueError('conditioned_ has been specified but dragonfly-energy '
                          'has failed to import.\n{}'.format(e))
 
+import uuid
+
 
 if all_required_inputs(ghenv.Component) and _run:
     room2d = []  # list of room2ds that will be returned
     for i, geo in enumerate(_geo):
         # get the name for the Room2D
         if _name_ is None:  # make a default Room2D name
-            name = "Room_{}".format(scriptcontext.sticky["room_count"])
-            scriptcontext.sticky["room_count"] += 1
+            name = "Building_{}_{}".format(scriptcontext.sticky["bldg_count"],
+                                           str(uuid.uuid4())[:8])
+            scriptcontext.sticky["bldg_count"] += 1
         else:
-            name = '{}_{}'.format(_name_, i + 1)
-        
+            display_name = '{}_{}'.format(_name_, i + 1)
+            name = clean_and_id_string(display_name)
+
         # create the Room2D
         room = Room2D(name, to_face3d(geo)[0], _flr_to_ceiling, tolerance=tolerance)
-        
+        if _name_ is not None:
+            room.display_name = display_name
+
         # assign the program
         if _program_ is not None:
             if isinstance(_program_, str):
-                _program_ = program_type_by_name(_program_)
+                _program_ = program_type_by_identifier(_program_)
             room.properties.energy.program_type = _program_ 
         else:  # generic office program by default
             try:
@@ -108,7 +122,7 @@ if all_required_inputs(ghenv.Component) and _run:
         # assign the construction set
         if _constr_set_ is not None:
             if isinstance(_constr_set_, str):
-                _constr_set_ = construction_set_by_name(_constr_set_)
+                _constr_set_ = construction_set_by_identifier(_constr_set_)
             room.properties.energy.construction_set = _constr_set_
         
         # assign an ideal air system
