@@ -18,8 +18,9 @@ Create a Dragonfly Story from individual Dragonfly Room2D objects.
             this Story to the floor of the story above this one (if it exists).
             If None, this value will be the maximum floor_to_ceiling_height of the
             input _room_2ds.
-        _name_:  A name for the Story. If the name is not provided a random
-            name will be assigned.
+        _name_: Text to set the name for the Story, which will also be incorporated
+            into unique Story identifier. If the name is not provided a random
+            one will be assigned.
         multiplier_: An integer with that denotes the number of times that this
             Story is repeated over the height of the building. Default: 1.
         _constr_set_: Text for the construction set of the Story, which is used
@@ -37,7 +38,7 @@ Create a Dragonfly Story from individual Dragonfly Room2D objects.
 
 ghenv.Component.Name = "DF Story"
 ghenv.Component.NickName = 'Story'
-ghenv.Component.Message = '0.1.1'
+ghenv.Component.Message = '0.1.2'
 ghenv.Component.Category = "Dragonfly"
 ghenv.Component.SubCategory = '0 :: Create'
 ghenv.Component.AdditionalHelpFromDocStrings = "3"
@@ -49,6 +50,11 @@ try:
 except KeyError:  # first time that the component is running
     scriptcontext.sticky["story_count"] = 1
 
+try:  # import the core honeybee dependencies
+    from honeybee.typing import clean_and_id_string
+except ImportError as e:
+    raise ImportError('\nFailed to import honeybee:\n\t{}'.format(e))
+
 try:  # import the core dragonfly dependencies
     from dragonfly.story import Story
 except ImportError as e:
@@ -61,30 +67,37 @@ except ImportError as e:
 
 try:  # import the dragonfly-energy extension
     import dragonfly_energy
-    from honeybee_energy.lib.constructionsets import construction_set_by_name
+    from honeybee_energy.lib.constructionsets import construction_set_by_identifier
 except ImportError as e:
     if _constr_set_ is not None:
         raise ValueError('_constr_set_ has been specified but dragonfly-energy '
                          'has failed to import.\n{}'.format(e))
 
+import uuid
+
 
 if all_required_inputs(ghenv.Component):
     # duplicate the initial objects
     room2ds = [room.duplicate() for room in _room2ds]
-    
+
     # generate a default name
     if _name_ is None:  # get a default Story name
-        _name_ = "Story_{}".format(scriptcontext.sticky["story_count"])
+        name = "Story_{}_{}".format(scriptcontext.sticky["story_count"],
+                                    str(uuid.uuid4())[:8])
         scriptcontext.sticky["story_count"] += 1
-    
+    else:
+        name = clean_and_id_string(_name_)
+
     # set other defaults
     multiplier_ = multiplier_ if multiplier_ is not None else 1
-    
+
     # create the Story
-    story = Story(_name_, room2ds, _flr_to_flr_, multiplier_)
-    
+    story = Story(name, room2ds, _flr_to_flr_, multiplier_)
+    if _name_ is not None:
+        story.display_name = _name_
+
     # assign the construction set
     if _constr_set_ is not None:
         if isinstance(_constr_set_, str):
-            _constr_set_ = construction_set_by_name(_constr_set_)
+            _constr_set_ = construction_set_by_identifier(_constr_set_)
         story.properties.energy.construction_set = _constr_set_
\ No newline at end of file
